<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
	<title>{#paste.paste_word_desc}</title>
	<script type="text/javascript" src="../../tiny_mce_popup.js"></script>
	<script type="text/javascript" src="js/pasteword.js"></script>
	<link href="css/pasteword.css" rel="stylesheet" type="text/css" />
</head>
<body onresize="resizeInputs();" style="display:none; overflow:hidden;">
	<form name="source" onsubmit="saveContent();" action="#">
		<div class="title">{#paste.paste_word_desc}</div>

		<div>{#paste_dlg.word_title}</div>

		<div id="iframecontainer"></div>

		<div class="mceActionPanel">
			<div style="float: left">
				<input type="button" id="insert" name="insert" value="{#insert}" onclick="saveContent();" />
			</div>

			<div style="float: right">
				<input type="button" id="cancel" name="cancel" value="{#cancel}" onclick="tinyMCEPopup.close();" />
			</div>
		</div>
	</form>
</body>
</html>
