tinyMCE.addI18n('es.fullpage_dlg',{
title:"Propiedades del documento",
meta_tab:"General",
appearance_tab:"Apariencia",
advanced_tab:"Avanzado",
meta_props:"Informaci\u00F3n Meta",
langprops:"Lenguaje y codificaci\u00F3n",
meta_title:"T\u00EDtulo",
meta_keywords:"Palabras clave",
meta_description:"Descripci\u00F3n",
meta_robots:"Robots",
doctypes:"Tipo de doc.",
langcode:"C\u00F3digo del lenguaje",
langdir:"Direcci\u00F3n del lenguaje",
ltr:"Izquierda a derecha",
rtl:"Derecha a izquierda",
xml_pi:"Declaraci\u00F3n XML",
encoding:"Codificaci\u00F3n de caracteres",
appearance_bgprops:"Propiedades del fondo",
appearance_marginprops:"M\u00E1rgenes",
appearance_linkprops:"Colores del v\u00EDnculo",
appearance_textprops:"Propiedades de texto",
bgcolor:"Color de fondo",
bgimage:"Imagen de fondo",
left_margin:"Margen izquierdo",
right_margin:"Margen derecho",
top_margin:"Margen superior",
bottom_margin:"Margen inferior",
text_color:"Color del texto",
font_size:"Tama\u00F1o de fuente",
font_face:"Fuente",
link_color:"Color de v\u00EDnculo",
hover_color:"Color rat\u00F3n encima",
visited_color:"Color visitado",
active_color:"Color activo",
textcolor:"Color",
fontsize:"Tama\u00F1o de fuente",
fontface:"Fuente",
meta_index_follow:"Indexar y seguir los v\u00EDnculos",
meta_index_nofollow:"Indexar y no seguir los v\u00EDnculos",
meta_noindex_follow:"No indexar pero seguir v\u00EDnculos",
meta_noindex_nofollow:"No indexar y no seguir v\u00EDnculos",
appearance_style:"Propiedades de hoja de estilos y estilo",
stylesheet:"Hoja de estilo",
style:"Estilo",
author:"Autor",
copyright:"Copyright",
add:"Agregar nuevo elemento",
remove:"Eliminar elemento seleccionado",
moveup:"Mover elemento seleccionado hacia arriba",
movedown:"Mover elemento seleccionado hacia abajo",
head_elements:"Elemento Head",
info:"Informaci\u00F3n",
add_title:"Elemento Title",
add_meta:"Elemento Meta",
add_script:"Elemento Script",
add_style:"Elemento Style",
add_link:"Elemento Link",
add_base:"Elemento Base",
add_comment:"Nodo Comment",
title_element:"Elemento Title",
script_element:"Elemento Script",
style_element:"Elemento Style",
base_element:"Elemento Base",
link_element:"Elemento Link",
meta_element:"Elemento Meta",
comment_element:"Comentario",
src:"Src",
language:"Lenguaje",
href:"Href",
target:"Target",
type:"Tipo",
charset:"Charset",
defer:"Defer",
media:"Medio",
properties:"Propiedades",
name:"Nombre",
value:"Valor",
content:"Contenido",
rel:"Rel",
rev:"Rev",
hreflang:"Href lang",
general_props:"General",
advanced_props:"Avanzado"
});